@@ -8,9 +8,10 @@ class Logger(BaseModel):
     rotation: str = '00:00'
     log_path: str = "/var/log"
 
-    def initial(self, filename):
-        filename = '{}/{}'.format(self.log_path, filename)
-        logger.add(filename, rotation=self.rotation, retention=self.retention, compression=self.compression, level=self.level)
+    def initial(self, filename=None):
+        if filename!=None:
+            filename = '{}/{}'.format(self.log_path, filename)
+            logger.add(filename, rotation=self.rotation, retention=self.retention, compression=self.compression, level=self.level)
 
         return logger
 
