@@ -7,6 +7,7 @@ class Redis(BaseModel):
     host: str
     port: int = 6379
     db: int = 0
+    password: str = None
 
     redis: Any = None
     cache: Any = None
@@ -15,7 +16,7 @@ class Redis(BaseModel):
         return 'redis://{}:{}/{}'.format(self.host, self.port, self.db)
 
     def connect(self) -> StrictRedis:
-        return StrictRedis(host=self.host, port=self.port, db=self.db, decode_responses=True)
+        return StrictRedis(host=self.host, port=self.port, password=self.password, db=self.db, decode_responses=True)
 
     def instance(self) -> StrictRedis:
         if self.redis==None:
